summaryrefslogtreecommitdiff
path: root/editor/find_in_files.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'editor/find_in_files.cpp')
-rw-r--r--editor/find_in_files.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/editor/find_in_files.cpp b/editor/find_in_files.cpp
index 9444706fd2..fd685cf592 100644
--- a/editor/find_in_files.cpp
+++ b/editor/find_in_files.cpp
@@ -233,8 +233,9 @@ void FindInFiles::_scan_dir(String path, PackedStringArray &out_folders) {
break;
}
- // Ignore special dirs (such as .git and .import)
- if (file == "." || file == ".." || file.begins_with(".")) {
+ // Ignore special dirs (such as .git and project data directory)
+ String project_data_dir_name = ProjectSettings::get_singleton()->get_project_data_dir_name();
+ if (file.begins_with(".") || file == project_data_dir_name) {
continue;
}
if (dir->current_is_hidden()) {